@@ -1,7 +1,7 @@
 """
 Type annotations for amplifybackend service client paginators.
 
-[Open documentation](./paginators.md)
+[Open documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_amplifybackend/paginators.html)
 
 Usage::
 
@@ -29,19 +29,20 @@ __all__ = ("ListBackendJobsPaginator",)
 
 class ListBackendJobsPaginator(Boto3Paginator):
     """
-    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.81/reference/services/amplifybackend.html#AmplifyBackend.Paginator.ListBackendJobs)[Show boto3-stubs documentation](./paginators.md#listbackendjobspaginator)
+    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.92/reference/services/amplifybackend.html#AmplifyBackend.Paginator.ListBackendJobs)[Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_amplifybackend/paginators.html#listbackendjobspaginator)
     """
 
     def paginate(
         self,
+        *,
         AppId: str,
         BackendEnvironmentName: str,
         JobId: str = None,
         Operation: str = None,
         Status: str = None,
-        PaginationConfig: PaginatorConfigTypeDef = None,
+        PaginationConfig: PaginatorConfigTypeDef = None
     ) -> Iterator[ListBackendJobsResponseTypeDef]:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.81/reference/services/amplifybackend.html#AmplifyBackend.Paginator.ListBackendJobs.paginate)
-        [Show boto3-stubs documentation](./paginators.md#listbackendjobspaginator)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.92/reference/services/amplifybackend.html#AmplifyBackend.Paginator.ListBackendJobs.paginate)
+        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_amplifybackend/paginators.html#listbackendjobspaginator)
         """
